import setuptools

setuptools.setup(
    name='meroua',
    version='1.1',
    description='A module that defines a constant type in Python using Jython',
    author='Sahraoui Tarek Ziad',
    author_email='tziad2027@gmail.com',
    packages=setuptools.find_packages(),
    py_modules=['mymodule'],

)



class meroua:
    def __setattr__(self, name, value):
        if name in self.__dict__:
            raise AttributeError(f"can't set attribute '{name}'")
        self.__dict__[name] = value

c_ = meroua()